.. dask-awkward documentation master file, created by
   sphinx-quickstart on Fri Sep 24 13:43:52 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

dask-awkward
============

*Connecting Dask and Awkward Array.*

.. warning::

   dask-awkward is currently in alpha status: we welcome feedback but
   please know that there is no guaranteed API stability.

.. toctree::
   :maxdepth: 2
   :caption: Contents

   intro.rst
   terminology.rst

.. toctree::
   :maxdepth: 2
   :caption: API

   api_array.rst
   api_io.rst
   api_reducers.rst
   api_structure.rst

..   Indices and tables
..   ==================

..   * :ref:`genindex`
..   * :ref:`modindex`
..   * :ref:`search`
